@@ -42,7 +42,7 @@ def download_thread(
     vparams = VParams(kwargs)
     vthread = get_thread(thread_url)
 
-    configure_gallerydl(vparams)
+    configure_gallerydl(vparams, dest)
 
     posts_to_download = get_posts_to_download(vthread.posts, mode)
 
